@@ -1,5 +1,5 @@
 /* server.c --- Experimental SASL mechanism KERBEROS_V5, server side.
- * Copyright (C) 2003, 2004  Simon Josefsson
+ * Copyright (C) 2003-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -588,12 +588,10 @@ _gsasl_kerberos_v5_server_finish (Gsasl_session * sctx, void *mech_data)
   struct _Gsasl_kerberos_v5_server_state *state = mech_data;
 
   shishi_done (state->sh);
-  if (state->username)
-    free (state->username);
-  if (state->password)
-    free (state->password);
-  if (state->random)
-    free (state->random);
+
+  free (state->username);
+  free (state->password);
+  free (state->random);
   free (state);
 
   return GSASL_OK;
